package com.ruoyi.model.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.model.domain.OmsOrderEvaluation;

/**
 * 订单评价Service接口
 * 
 * @author daixiande
 */
public interface IOmsOrderEvaluationService extends IService<OmsOrderEvaluation> {
    /**
     * 查询订单评价
     * 
     * @param id 订单评价主键
     * @return 订单评价
     */
    OmsOrderEvaluation selectOmsOrderEvaluationById(Long id);

    /**
     * 查询订单评价列表
     * 
     * @param omsOrderEvaluation 订单评价
     * @return 订单评价集合
     */
    List<OmsOrderEvaluation> selectOmsOrderEvaluationList(OmsOrderEvaluation omsOrderEvaluation);

    /**
     * 新增订单评价
     * 
     * @param omsOrderEvaluation 订单评价
     * @return 结果
     */
    boolean insertOmsOrderEvaluation(OmsOrderEvaluation omsOrderEvaluation);

    /**
     * 修改订单评价
     * 
     * @param omsOrderEvaluation 订单评价
     * @return 结果
     */
    int updateOmsOrderEvaluation(OmsOrderEvaluation omsOrderEvaluation);

    /**
     * 批量删除订单评价
     * 
     * @param ids 需要删除的订单评价主键集合
     * @return 结果
     */
    boolean deleteOmsOrderEvaluationByIds(Long[] ids);

    /**
     * 删除订单评价信息
     * 
     * @param id 订单评价主键
     * @return 结果
     */
    boolean deleteOmsOrderEvaluationById(Long id);
}
