package com.ruoyi.model.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.OmsOrderEvaluation;
import com.ruoyi.model.service.IOmsOrderEvaluationService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 订单评价Controller
 * 
 * @author daixiande
 * @date 2025-08-06
 */
@RestController
@RequestMapping("/model/omsOrderEvaluation")
public class OmsOrderEvaluationController extends BaseController {
    @Autowired
    private IOmsOrderEvaluationService omsOrderEvaluationService;

    /**
     * 查询订单评价列表
     */
    @PreAuthorize("@ss.hasPermi('model:omsOrderEvaluation:list')")
    @GetMapping("/list")
    public TableDataInfo list(OmsOrderEvaluation omsOrderEvaluation) {
        startPage();
        List<OmsOrderEvaluation> list = omsOrderEvaluationService.selectOmsOrderEvaluationList(omsOrderEvaluation);
        return getDataTable(list);
    }

    /**
     * 导出订单评价列表
     */
    @PreAuthorize("@ss.hasPermi('model:omsOrderEvaluation:export')")
    @Log(title = "订单评价", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(OmsOrderEvaluation omsOrderEvaluation) {
        List<OmsOrderEvaluation> list = omsOrderEvaluationService.selectOmsOrderEvaluationList(omsOrderEvaluation);
        ExcelUtil<OmsOrderEvaluation> util = new ExcelUtil<OmsOrderEvaluation>(OmsOrderEvaluation.class);
        return util.exportExcel(list, "订单评价数据");
    }

    /**
     * 获取订单评价详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:omsOrderEvaluation:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return AjaxResult.success(omsOrderEvaluationService.selectOmsOrderEvaluationById(id));
    }

    /**
     * 新增订单评价
     */
    @PreAuthorize("@ss.hasPermi('model:omsOrderEvaluation:add')")
    @Log(title = "订单评价", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody OmsOrderEvaluation omsOrderEvaluation) {
        return toAjax(omsOrderEvaluationService.insertOmsOrderEvaluation(omsOrderEvaluation));
    }

    /**
     * 修改订单评价
     */
    @PreAuthorize("@ss.hasPermi('model:omsOrderEvaluation:edit')")
    @Log(title = "订单评价", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody OmsOrderEvaluation omsOrderEvaluation) {
        return toAjax(omsOrderEvaluationService.updateOmsOrderEvaluation(omsOrderEvaluation));
    }

    /**
     * 删除订单评价
     */
    @PreAuthorize("@ss.hasPermi('model:omsOrderEvaluation:remove')")
    @Log(title = "订单评价", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(omsOrderEvaluationService.deleteOmsOrderEvaluationByIds(ids));
    }
}
